weblogolib.colorscheme.ColorScheme

Package weblogolib :: Module colorscheme :: Class ColorScheme |

# Class ColorScheme

source code

    object --+
             |
            ColorScheme

    A coloring of an alphabet.

    title : string            -- A human readable description
    defualt_color : Color           --
    groups : list of color groups
    alphabet : string               -- The set of colored symbols
    color -- A map between a symbol and a Coloring

Instance Methods
__init__(self, groups=[], title="", description="", default_color="black", alphabet=seq.generic_alphabet) | source code
color(self, symbol) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, groups=[], title="", description="", default_color="black", alphabet=seq.generic_alphabet) (Constructor) | source code
Overrides: object.__init__